@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2011 Olivier Girondel
+ *  Copyright 1994-2012 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -24,7 +24,7 @@
 u_long id = 1095629101;
 u_long options = BE_NONE;
 
-
+#ifndef FIXED
 u_short out_width;
 u_short out_height;
 #define out_buffsize (out_width * out_height)
@@ -32,7 +32,8 @@ static struct SwsContext *sws_context = NULL;
 static uint8_t *bufp = NULL, *dstbufp = NULL;
 static uint8_t *bufp_src[3] = {NULL, NULL, NULL}; /* FIXME not 4 ? */
 static uint8_t *dstbufp_src[3] = {NULL, NULL, NULL}; /* FIXME only first is used ? */
-
+#endif
+static Buffer8_t *out;
 static Uint32 colors[256];
 
 
@@ -77,6 +78,7 @@ SDL_refresh_32bpp(Context_t *ctx, SDL_Surface *sc)
   u_long k = 0;
   Pixel_t *cptr = NULL;
   Uint32 *buf;
+#ifndef FIXED
   int srcstride[3] = {WIDTH*4, 0, 0};
   int dststride[3] = {out_width*4, 0, 0};
   int ret;
@@ -89,17 +91,21 @@ SDL_refresh_32bpp(Context_t *ctx, SDL_Surface *sc)
     dstbufp = xcalloc(4*out_buffsize, sizeof(uint8_t));
     dstbufp_src[0] = sc->pixels;
   }
+#endif
 
-  /* XXX les 2 flips, c'est sale --oliv3 */
-  Buffer8_flip_x(src);
-  cptr = src->buffer;
+  Buffer8_copy(src, out);
+  Buffer8_flip_x(out);
+  cptr = out->buffer;
 
+#ifdef FIXED
+  buf = sc->pixels;
+#else
   buf = (Uint32 *)bufp;
+#endif
   for (k = 0; k < BUFFSIZE; k++)
     *buf++ = colors[*cptr++];
 
-  Buffer8_flip_x(src);
-
+#ifndef FIXED
   if (NULL == sws_context)
     sws_context = sws_getContext(WIDTH, HEIGHT, PIX_FMT_RGB32,
 				 out_width, out_height, PIX_FMT_RGB32,
@@ -110,6 +116,7 @@ SDL_refresh_32bpp(Context_t *ctx, SDL_Surface *sc)
   ret = sws_scale(sws_context, (const uint8_t * const *)bufp_src, srcstride, 0, HEIGHT, dstbufp_src, dststride);
   if (ret < 0)
     xerror("sws_scale\n");
+#endif
 }
 
 
@@ -172,7 +179,8 @@ SDL_get_event(Context_t *ctx)
 	break;
       }
       break;
-			
+
+#ifndef FIXED
     case SDL_VIDEORESIZE:
       out_width = (evt.resize.w >= 8) ? evt.resize.w : out_width;
       out_height = (evt.resize.h >= 8) ? evt.resize.h : out_height;
@@ -184,6 +192,7 @@ SDL_get_event(Context_t *ctx)
 
       biniou_sdl_set_videomode(out_width, out_height, drv.sc->flags);
       break;
+#endif
 
     default:
       break;
@@ -239,10 +248,14 @@ create(__attribute__ ((unused)) Context_t *ctx)
     SDL_DOUBLEBUF | SDL_HWACCEL |
     SDL_RLEACCEL;
 
+#ifndef FIXED
   flags |= SDL_RESIZABLE;
   out_width = WIDTH;
   out_height = HEIGHT;
   biniou_sdl_set_videomode(out_width, out_height, flags);
+#else
+  biniou_sdl_set_videomode(WIDTH, HEIGHT, flags);
+#endif
 
   window_title = g_strdup_printf("Le Biniou (%dx%d)", WIDTH, HEIGHT);
   SDL_WM_SetCaption(window_title, NULL);
@@ -253,18 +266,23 @@ create(__attribute__ ((unused)) Context_t *ctx)
   SDL_ShowCursor(SDL_DISABLE);
 #endif
   SDL_EnableKeyRepeat(SDL_DEFAULT_REPEAT_DELAY, SDL_DEFAULT_REPEAT_INTERVAL);
+
+  out = Buffer8_new();
 }
 
 
 void
 destroy(__attribute__ ((unused)) Context_t *ctx)
 {
+#ifndef FIXED
   sws_freeContext(sws_context);
   xfree(bufp);
   xfree(dstbufp);
+#endif
   SDL_FreeSurface(drv.sc);
   ttf_quit();
   SDL_Quit();
+  Buffer8_delete(out);
 }
 
 
