@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2011 Olivier Girondel
+ *  Copyright 1994-2012 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -26,7 +26,12 @@
 static TTF_Font *font = NULL;
 #define PTSIZE     14
 
+#ifndef FIXED
 extern u_short out_width, out_height;
+#else
+#define out_width  WIDTH
+#define out_height HEIGHT
+#endif
 
 static char enabled = 1;
 
