@@ -4,8 +4,7 @@
 #include <arpa/inet.h>
 #include "context.h"
 #include "sequences.h"
-
-#define BUFLEN 1024
+#include "plugins.h"
 
 /* commands */
 #define CMD_CHAR             'C'
@@ -14,5 +13,12 @@
 #define UPDATE_COLORMAP_CHAR 'C'
 #define UPDATE_PICTURE_CHAR  'P'
 #define UPDATE_SEQUENCE_CHAR 'S'
+#define INFO_CHAR            'I'
+#define WEBCAM_CHAR          'W'
+#define BINIOU_CHAR          'B'
+
+void info(const char *, ...);
+
+ssize_t write_exact(const u_char *, const ssize_t);
 
 #endif /* __ERLANG_H */
