@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2011 Olivier Girondel
+ *  Copyright 1994-2012 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -32,10 +32,6 @@
  *
  */
 
-extern FILE *out;
-extern void xfwrite(const void *, size_t, size_t, FILE *);
-
-
 static u_char
 get_volume(const Context_t *ctx)
 {
@@ -57,39 +53,41 @@ v3(const Context_t *ctx)
   uint32_t proto, proto2;
   uint32_t total, total2;
   Pixel_t *src;
+  /* TODO check ret */
+  int ret;
 
   /* send packet size */
   total = sizeof(uint32_t)+sizeof(u_char)+4*sizeof(uint16_t)+BUFFSIZE*3*sizeof(u_char);
   total2 = htonl(total);
-  xfwrite((const void *)&total2, sizeof(uint32_t), 1, out);
+  ret = write_exact((const u_char *)&total2, sizeof(uint32_t));
   
   /* protocol version */
   proto = 3;
   proto2 = htonl(proto);
-  xfwrite((const void *)&proto2, sizeof(uint32_t), 1, out);
+  ret = write_exact((const u_char *)&proto2, sizeof(uint32_t));
 
   /* send volume */
   volume = get_volume(ctx);
-  xfwrite((const void *)&volume, sizeof(u_char), 1, out);
+  ret = write_exact((const u_char *)&volume, sizeof(uint8_t));
   
   /* send width, height */
   width2 = htons(width);
   height2 = htons(height);
-  xfwrite((const void *)&width2, sizeof(uint16_t), 1, out);
-  xfwrite((const void *)&height2, sizeof(uint16_t), 1, out);
+  ret = write_exact((const u_char *)&width2, sizeof(uint16_t));
+  ret = write_exact((const u_char *)&height2, sizeof(uint16_t));
 
   /* send pixel format */
   pf = GL_RGB;
   pf2 = htons(pf);
-  xfwrite((const void *)&pf2, sizeof(uint16_t), 1, out);
+  ret = write_exact((const u_char *)&pf2, sizeof(uint16_t));
 
   /* send pixel type */
   pt = GL_UNSIGNED_BYTE;
   pt2 = htons(pt);
-  xfwrite((const void *)&pt2, sizeof(uint16_t), 1, out);
+  ret = write_exact((const u_char *)&pt2, sizeof(uint16_t));
 
   /* send picture */
   src = export_RGB_active_buffer(ctx, 0);
-  xfwrite((const void *)src, sizeof(u_char), BUFFSIZE*3, out);
+  ret = write_exact(src, BUFFSIZE*3*sizeof(Pixel_t));
   xfree(src);
 }
