@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2011 Olivier Girondel
+ *  Copyright 1994-2012 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -28,9 +28,6 @@
  *  [U][C|P|S][uint32_t id]  // update event
  */
 
-extern int write_exact(const u_char *, const int);
-
-
 extern uint32_t last_colormap;
 extern uint32_t last_picture;
 extern uint32_t last_sequence;
@@ -58,7 +55,7 @@ v7_send_event(const Event_t *e)
   proto2 = htonl(proto);
   ret = write_exact((const u_char *)&proto2, sizeof(uint32_t));
 
-  val = 'C';
+  val = CMD_CHAR;
   ret = write_exact(&val, sizeof(u_char));
   val = e->to;
   ret = write_exact(&val, sizeof(u_char));
@@ -111,28 +108,26 @@ v7_send_id(const u_char what, const uint32_t id)
 
 
 static void
-v7_send_sequence(const uint32_t id)
+v7_send_sequence(Sequence_t *seq)
 {
   uint32_t proto = 7, proto2;
   uint32_t total, total2;
-  uint32_t id2;
+  uint32_t id, id2;
   Pixel_t *src;
   u_char val;
   int ret;
-  Sequence_t *seq;
   GList *tmp;
   uint8_t seq_size, i;
-
-  seq = Sequences_find(id);
-  assert(NULL != seq);
+  
   seq_size = Sequence_size(seq);
-
+  
   /* send packet size */
   total = sizeof(uint32_t)           /* proto */
     + 2*sizeof(u_char)               /* 'US' */
     + sizeof(uint32_t)               /* sequence id */
+    + sizeof(uint32_t)               /* lens id or 0 */
     + sizeof(uint8_t)                /* sequence size */
-    + (seq_size * sizeof(uint32_t)); /* N plugins */ /* TODO plugin_id -> uint32_t */
+    + (seq_size * (sizeof(uint32_t)+sizeof(u_char))); /* N plugins */ /* TODO plugin_id -> uint32_t */
   total2 = htonl(total);
   ret = write_exact((const u_char *)&total2, sizeof(uint32_t));
 
@@ -146,17 +141,30 @@ v7_send_sequence(const uint32_t id)
   ret = write_exact(&val, sizeof(u_char));
 
   /* sequence id */
-  id2 = htonl(id);
+  id2 = htonl(seq->id);
   ret = write_exact((const u_char *)&id2, sizeof(uint32_t));
 
   /* the sequence */
+  /*   - lens plugin id or 0 */
+  id = (NULL != seq->lens) ? seq->lens->id : 0;
+  id2 = htonl(id);
+  ret = write_exact((const u_char *)&id2, sizeof(uint32_t));
+
+  /*   - size of the sequence */
   ret = write_exact((const u_char *)&seq_size, sizeof(uint8_t));
+
+  /*   - layers */
   tmp = seq->layers;
   for (i = 0; i < seq_size; i++) {
     Layer_t *l = (Layer_t *)tmp->data;
 
+    /* plugin id */
     id2 = htonl(l->plugin->id);
     ret = write_exact((const u_char *)&id2, sizeof(uint32_t));
+
+    /* layer mode */
+    ret = write_exact((const u_char *)&l->mode, sizeof(u_char));
+
     tmp = g_list_next(tmp);
   }
 }
@@ -167,6 +175,13 @@ v7(Context_t *ctx)
 {
   v7_send_events(ctx);
 
+  if (send_sequence_update)
+    if (ctx->sm->cur->id != last_sequence) {
+      v7_send_sequence(ctx->sm->cur);
+      last_sequence = ctx->sm->cur->id;
+      send_colormap_update = send_picture_update = 0;
+    }
+
   if (send_colormap_update)
     if (ctx->sm->cur->cmap_id != last_colormap) {
       v7_send_id(UPDATE_COLORMAP_CHAR, ctx->sm->cur->cmap_id);
@@ -178,10 +193,4 @@ v7(Context_t *ctx)
       v7_send_id(UPDATE_PICTURE_CHAR, ctx->sm->cur->picture_id);
       last_picture = ctx->sm->cur->picture_id;
     }
-
-  if (send_sequence_update)
-    if (ctx->sm->cur->id != last_sequence) {
-      v7_send_sequence(ctx->sm->cur->id);
-      last_sequence = ctx->sm->cur->id;
-    }
 }
