@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2011 Olivier Girondel
+ *  Copyright 1994-2012 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -44,7 +44,9 @@ exit_if_r00t()
 void
 biniou_new(const char *datadir, const char *pluginsdir,
 	   const char *schemes, const char *themes,
+#ifndef FIXED
 	   const u_short width, const u_short height,
+#endif
 	   const u_char options)
 {
   char *buf;
@@ -54,8 +56,10 @@ biniou_new(const char *datadir, const char *pluginsdir,
   if (options & B_INIT_VERBOSE)
     libbiniou_verbose = 1;
 
+#ifndef FIXED
   WIDTH = width;
   HEIGHT = height;
+#endif
 
   /* PRNG */
   b_rand_init();
@@ -144,7 +148,7 @@ biniou_start()
   }
 
   assert(context->sm->cur != NULL);
-  assert(context->sm->new != NULL);
+  assert(context->sm->next != NULL);
   Context_set(context);
 
   /* XXX */
