@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2011 Olivier Girondel
+ *  Copyright 1994-2012 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -45,6 +45,7 @@ typedef struct Buffer8_s {
 
 
 Buffer8_t *Buffer8_new(void);
+Buffer8_t *Buffer8_clone(const Buffer8_t *);
 void Buffer8_delete(Buffer8_t *);
 
 
@@ -466,4 +467,27 @@ Buffer8_flip_x(Buffer8_t *buff)
   }
 }
 
+
+static inline void
+Buffer8_flip_y(Buffer8_t *buff)
+{
+  u_short j;
+
+  for (j = 0; j < HEIGHT; j++) {
+    u_short i;
+
+    for (i = 0; i < HWIDTH; i++) {
+      Pixel_t tmp;
+
+      tmp = buff->buffer[j*WIDTH+i];
+      buff->buffer[j*WIDTH+i] = buff->buffer[j*WIDTH+WIDTH-i-1];
+      buff->buffer[j*WIDTH+WIDTH-i-1] = tmp;
+    }
+  }
+}
+
+
+void gray_scale(Pixel_t *, const uint16_t, const uint16_t, const Pixel_t *);
+void Buffer8_substract_y(const Buffer8_t *, const Buffer8_t *, const Pixel_t, const Buffer8_t *);
+
 #endif /* __BINIOU_BUFFER_8BITS_H */
