@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2011 Olivier Girondel
+ *  Copyright 1994-2012 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -34,8 +34,10 @@ usage()
 	 "\t-r, --random <mode>\tSet auto-random mode\n"
 	 "\t-s, --screen <mode>\tSet On Screen Display mode\n"
 	 "\t-v, --version\t\tDisplay the version and exit\n"
+#ifndef FIXED
 	 "\t-x, --width <width>\tSet width\n"
 	 "\t-y, --height <height>\tSet height\n"
+#endif
 	 "\t-p, --pidfile <file>\tSet the PID file\n"
 	 "\t-t, --themes <themes>\tComma-separated list of themes to use\n"
 	 "\n"
@@ -70,8 +72,10 @@ getargs(int argc, char **argv)
 		  {"output", required_argument, NULL, 'o'},
 		  {"random", required_argument, NULL, 'r'},
 		  {"screen", required_argument, NULL, 's'},
+#ifndef FIXED
 		  {"width", required_argument, NULL, 'x'},
 		  {"height", required_argument, NULL, 'y'},
+#endif
 		  {"version", no_argument, NULL, 'v'},
 		  {"pidfile", required_argument, NULL, 'p'},
 		  {"themes", required_argument, NULL, 't'},
@@ -80,9 +84,17 @@ getargs(int argc, char **argv)
 
   
   /* Get command line arguments */
+#ifdef FIXED
+  while ((ch = getopt_long(argc, argv, "b:d:fhi:m:o:p:r:s:t:v", long_opt, NULL)) != -1)
+#else
   while ((ch = getopt_long(argc, argv, "b:d:fhi:m:o:p:r:s:t:x:y:v", long_opt, NULL)) != -1)
+#endif
+#else
+#ifdef FIXED
+  while ((ch = getopt(argc, argv, "b:d:fhi:m:o:p:r:s:t:v")) != -1)
 #else
   while ((ch = getopt(argc, argv, "b:d:fhi:m:o:p:r:s:t:x:y:v")) != -1)
+#endif
 #endif
     switch (ch) {
     case 'b':
@@ -158,6 +170,7 @@ getargs(int argc, char **argv)
       exit(0);
       break;
 
+#ifndef FIXED
     case 'x':
       width = xatol(optarg);
       printf("[c] Width set to %i\n", width);
@@ -167,6 +180,7 @@ getargs(int argc, char **argv)
       height = xatol(optarg);
       printf("[c] Height set to %i\n", height);
       break;
+#endif
 		  
     case 'p':
       if (pid_file == NULL)
