@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2011 Olivier Girondel
+ *  Copyright 1994-2012 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -21,7 +21,9 @@
 #define __BINIOU_CONSTANTS_H
 
 /* maximum logical buffer size */
+#ifndef FIXED
 extern unsigned short WIDTH, HEIGHT;
+#endif
 #define BUFFSIZE   (unsigned long)(WIDTH*HEIGHT)
 
 /* min/max indices */
