@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2011 Olivier Girondel
+ *  Copyright 1994-2012 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -23,12 +23,33 @@
 #include "pictures.h"
 #include "colormaps.h"
 #include "sequences.h"
+#include "webcam.h"
 
 
 #define DELAY_MIN 15
 #define DELAY_MAX 30
 
 
+static void
+Context_open_webcam(Context_t *ctx)
+{
+  fd = -1;
+
+  pthread_mutex_init(&ctx->cam_mtx, NULL);
+
+  parse_options();
+  if (-1 != open_device())
+    if (-1 != init_device()) {
+      ctx->has_cam = 1;
+      enumerate_cids();
+      start_capturing();
+    }
+
+  if (ctx->has_cam)
+    pthread_create(&thr, NULL, loop, (void *)ctx);
+}
+
+
 Context_t *
 Context_new()
 {
@@ -44,6 +65,9 @@ Context_new()
       printf("%d ", i);
     ctx->buffers[i] = Buffer8_new();
   }
+  ctx->cam_ref = Buffer8_new();
+  for (i = 0; i < CAM_SAVE; i++)
+    ctx->cam_save[i] = Buffer8_new();
   printf("\n");
 
   if (pictures != NULL) {
@@ -90,16 +114,35 @@ Context_new()
 
   ctx->outputs = NULL;
 
+  ctx->cam = CAM_IN_BUFFER;
+  ctx->has_cam = 0;
+
+  Context_open_webcam(ctx);
+
   return ctx;
 }
 
 
+static void
+Context_close_webcam(Context_t *ctx)
+{
+  pthread_join(thr, NULL);
+  stop_capturing();
+  uninit_device();
+  close_device();
+  free(dev_name);
+}
+
+
 void
 Context_delete(Context_t *ctx)
 {
   int i;
   GSList *outputs = ctx->outputs;
 
+  if (ctx->has_cam)
+    Context_close_webcam(ctx);
+
   if (libbiniou_verbose)
     printf("[i] %lu frames, %lu events\n", ctx->frames, ctx->nb_events);
 
@@ -120,6 +163,9 @@ Context_delete(Context_t *ctx)
       printf("%d ", i);
     Buffer8_delete(ctx->buffers[i]);
   }
+  Buffer8_delete(ctx->cam_ref);
+  for (i = 0; i < CAM_SAVE; i++)
+    Buffer8_delete(ctx->cam_save[i]);
   if (libbiniou_verbose)
     printf("\n");
 
@@ -263,7 +309,7 @@ Context_add_rand(Sequence_t *seq,
   } while (Sequence_find(seq, p) != NULL);
 
   if (*p->options & BEQ_FLUSH)
-    Sequence_clear(seq);
+    Sequence_clear(seq, 0);
 
   Sequence_insert(seq, p);
 
@@ -454,6 +500,10 @@ Context_set_sequence(Context_t *ctx, const uint32_t id)
 {
   Sequence_t *seq = Sequences_find(id);
 
+  if (NULL == seq)
+    if (ctx->sm->transient->id == id)
+      seq = ctx->sm->transient;
+
   assert(NULL != seq);
   ctx->sm->curseq = seq->layers;
   Sequence_copy(seq, ctx->sm->next);
@@ -475,6 +525,9 @@ Context_use_bank(Context_t *ctx, const u_char bank)
       printf("[s] Set sequence: %li\n", id);
 
     seq = Sequences_find(id);
+    if (NULL == seq)
+      if (ctx->sm->transient->id == id)
+	seq = ctx->sm->transient;
     assert(NULL != seq);
     ctx->sm->curseq = seq->layers;
     Sequence_copy(seq, ctx->sm->next);
@@ -506,3 +559,15 @@ passive_buffer(const Context_t *ctx)
 {
   return ctx->buffers[PASSIVE_BUFFER];
 }
+
+
+void
+Context_push_webcam(Context_t *ctx, Buffer8_t *buff)
+{
+  int i;
+
+  Buffer8_delete(ctx->cam_save[CAM_SAVE-1]);
+  for (i = CAM_SAVE-1; i >= 1; i--)
+    ctx->cam_save[i] = ctx->cam_save[i-1];
+  ctx->cam_save[0] = buff;
+}
