@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2011 Olivier Girondel
+ *  Copyright 1994-2012 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -33,11 +33,15 @@
 
 enum RandomMode { BR_NONE=0, BR_SEQUENCES, BR_SCHEMES, BR_BOTH } RandomMode_e;
 
-#define NSCREENS 3
+#define NSCREENS 5
 #define ACTIVE_BUFFER  0
 #define PASSIVE_BUFFER 1
 #define SAVE_BUFFER    2
+#define CAM_IN_BUFFER  3
+#define CAM_OUT_BUFFER 4
 
+/* store the last N frames from the webcam -same as EffectTV */
+#define CAM_SAVE 32
 
 typedef struct BKey_s {
   u_short val;
@@ -52,12 +56,17 @@ typedef struct Context_s {
   Input_t   *input;
 
   /* Buffers */
-  Buffer8_t  *buffers[NSCREENS];
+  Buffer8_t *buffers[NSCREENS];
   /* 0 = active_buffer
    * 1 = passive_buffer - for double-buffering
    * 2 = save_buffer    - push/pop screen for lens effects
+   * 3 = camera input
+   * 4 = camera output
    */
 
+  /* webcam */
+  Buffer8_t *cam_save[CAM_SAVE], *cam_ref;
+
   /* Faders */
   PictFader_t *pf;
   Alarm_t *a_picts;
@@ -98,6 +107,11 @@ typedef struct Context_s {
   void (*events_cb)(struct Context_s *, const BKey_t *); /* events callback */
 
   u_char   bank; /* the bank used */
+
+  /* Webcam */
+  u_char has_cam;
+  pthread_mutex_t cam_mtx;
+  u_char cam;
 } Context_t;
 
 
@@ -180,4 +194,6 @@ export_RGB_active_buffer(const Context_t *, const u_char);
 void Context_use_bank(Context_t *, const u_char);
 void Context_clear_bank(Context_t *, const u_char);
 
+void Context_push_webcam(Context_t *, Buffer8_t *);
+
 #endif /* __BINIOU_CONTEXT_H */
