@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2011 Olivier Girondel
+ *  Copyright 1994-2012 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -104,7 +104,7 @@ Context_event(Context_t *ctx, const Event_t *e)
   switch (e->cmd) {
   case BC_QUIT:
     if (e->arg0 == BA_SAVE)
-      Sequence_save(ctx->sm->cur, 0);
+      Sequence_save(ctx->sm->cur, 0, SequenceManager_is_transient(ctx->sm, ctx->sm->cur));
     ctx->running = 0;
     return 1;
     break;
@@ -378,6 +378,15 @@ Context_event(Context_t *ctx, const Event_t *e)
     }
     break;
 
+  case BC_SET:
+    if (e->arg0 == BA_WEBCAM) {
+      pthread_mutex_lock(&ctx->cam_mtx);
+      Buffer8_copy(ctx->buffers[CAM_IN_BUFFER], ctx->cam_ref);
+      pthread_mutex_unlock(&ctx->cam_mtx);
+      return 1;
+    }
+    break;
+
   default:
     break;
   }
