@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2011 Olivier Girondel
+ *  Copyright 1994-2012 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -79,6 +79,7 @@ process(GKeyFile *kf)
     error = NULL;
   }
 
+#ifndef FIXED
   kf_width = g_key_file_get_integer(kf, SCREEN, "Width", &error);
   if (NULL == error) {
     if (kf_width > 0)
@@ -102,6 +103,7 @@ process(GKeyFile *kf)
     g_error_free(error);
     error = NULL;
   }
+#endif
 
   kf_fps = g_key_file_get_integer(kf, ENGINE, "Fps", &error);
   if (NULL == error) {
