@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2011 Olivier Girondel
+ *  Copyright 1994-2012 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -134,7 +134,15 @@ main(int argc, char **argv)
     do_banner();
 
   /* Initialize library */
-  biniou_new(data_dir, base_dir, schemes_file, themes, width, height, B_INIT_ALL|B_INIT_VERBOSE);
+  biniou_new(data_dir, base_dir, schemes_file, themes,
+#ifndef FIXED
+	     width, height,
+#endif
+	     B_INIT_ALL
+#ifdef DEBUG
+	     |B_INIT_VERBOSE
+#endif
+	     );
   xfree(themes);
 
   biniou_set_max_fps(max_fps);
