@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2011 Olivier Girondel
+ *  Copyright 1994-2012 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -40,8 +40,10 @@ extern char *input_plugin;
 extern char *output_plugin;
 extern char fullscreen;
 extern long max_fps;
+#ifndef FIXED
 extern u_short width;
 extern u_short height;
+#endif
 extern enum RandomMode random_mode;
 extern enum OSDMode osd_mode;
 extern char *pid_file;
