@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2011 Olivier Girondel
+ *  Copyright 1994-2012 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -17,7 +17,6 @@
  *  along with lebiniou. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <libswscale/swscale.h>
 #include "picture_8bits.h"
 #include "pnglite.h"
 
@@ -118,37 +117,6 @@ PNG_to_Y(const png_t *png, const u_char *src)
 }
 
 
-static Pixel_t *
-rescale(const png_t *png, Pixel_t *src, const u_short dst_width, const u_short dst_height)
-{
-  Pixel_t *res = NULL;
-  struct SwsContext *sws_context = NULL;
-  int srcStride[4]={0,0,0,0}, dstStride[4]={0,0,0,0};
-  uint8_t *srcSlice[4]={NULL,NULL,NULL,NULL}, *dst[4]={NULL,NULL,NULL,NULL};
-  int ret;
-
-  res = xmalloc(dst_width*dst_height*sizeof(Pixel_t));
-  sws_context = sws_getContext(png->width, png->height, PIX_FMT_GRAY8,
-			       dst_width, dst_height, PIX_FMT_GRAY8,
-			       SWS_FAST_BILINEAR, NULL, NULL, NULL);
-  if (NULL == sws_context)
-    xerror("sws_getContext\n");
-
-  srcStride[0] = png->width;
-  dstStride[0] = dst_width;
-  srcSlice[0] = src;
-  dst[0] = res;
-
-  ret = sws_scale(sws_context, (const uint8_t * const *)srcSlice, srcStride, 0, png->height, dst, dstStride);
-  if (ret < 0)
-    xerror("sws_scale\n");
-
-  sws_freeContext(sws_context);
-
-  return res;
-}
-
-
 static int
 Picture8_load_PNG(Picture8_t *pic, const char *filename)
 {
@@ -171,15 +139,15 @@ Picture8_load_PNG(Picture8_t *pic, const char *filename)
     if (PNG_NO_ERROR == res) {
       Pixel_t *y = NULL;
       Pixel_t *dst = pic->buff->buffer;
-      xfree(dst);
+
       y = PNG_to_Y(&png, data);
       xfree(data);
 
       if ((png.width != WIDTH) || (png.height != HEIGHT)) {
-	Pixel_t *scaled = rescale(&png, y, WIDTH, HEIGHT);
+	gray_scale(dst, png.width, png.height, y);
 	xfree(y);
-	pic->buff->buffer = scaled;
       } else {
+	xfree(pic->buff->buffer);
 	pic->buff->buffer = y;
       }
       Buffer8_flip_x(pic->buff);
