@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2011 Olivier Girondel
+ *  Copyright 1994-2012 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -17,6 +17,7 @@
  *  along with lebiniou. If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <inttypes.h>
 #include "globals.h"
 #include "pictures.h"
 #include "brandom.h"
@@ -47,7 +48,7 @@ Pictures_new(const char *basedir, const char *themes)
   DIR *dir;
   struct dirent *entry;
   GSList *tmp = NULL;
-  u_short size = 0;
+  uint16_t size = 0;
   GSList *t;
   PBar_t *pb = NULL;
   gchar **tokens, **theme;
@@ -93,28 +94,38 @@ Pictures_new(const char *basedir, const char *themes)
       if (entry->d_name[0] == '.')
 	continue;
 
-      pic = Picture8_new();
       hash = FNV_hash(entry->d_name);
 
-      if (Picture8_load(pic, hash, directoryname,
-		      entry->d_name) != 0) {
-	Picture8_delete(pic);
-	continue;
-      }
-
-      tmp = g_slist_prepend(tmp, (gpointer)pic);
-      size++;
-
-      if (libbiniou_verbose && !(size % 5))
-	pbar_step(pb);
-
+      char ignore = 0;
       for (t = g_slist_next(tmp);
 	   t != NULL;
 	   t = g_slist_next(t))
-	if (((Picture8_t *)t->data)->id == hash)
-	  xerror("Duplicated picture hash: %s / %s, %li\n",
-		 ((Picture8_t *)t->data)->name, entry->d_name, hash);
+	if (((Picture8_t *)t->data)->id == hash) {
+	  const char *name = ((Picture8_t *)t->data)->name;
+
+	  if (strcmp(name, entry->d_name))
+	    printf("[!] Ignoring picture '%s'\n"
+		   "[!]   (same hash as '%s': %"PRIu32")\n",
+		   entry->d_name, name, hash);
+	  ignore = 1;
+	}
+
+      if (!ignore) {
+	pic = Picture8_new();
+
+	if (Picture8_load(pic, hash, directoryname,
+			  entry->d_name) != 0) {
+	  Picture8_delete(pic);
+	} else {
+	  size++;
+	  if (libbiniou_verbose && !(size % 5))
+	    pbar_step(pb);
+
+	  tmp = g_slist_prepend(tmp, (gpointer)pic);
+	}
+      }
     }
+
     if (closedir(dir) == -1)
       xperror("closedir");
     g_free(directoryname);
@@ -130,7 +141,7 @@ Pictures_new(const char *basedir, const char *themes)
   }
 
   if (size) {
-    u_short i;
+    uint16_t i;
 
     pictures->pics = xmalloc(size*sizeof(Picture8_t *));
     for (i = 0, t = tmp;
@@ -154,7 +165,7 @@ void
 Pictures_delete()
 {
   if (pictures != NULL) {
-    u_short i;
+    uint16_t i;
 
     for (i = 0; i < pictures->size; i++)
       Picture8_delete(pictures->pics[i]);
@@ -165,9 +176,9 @@ Pictures_delete()
 
 
 const char *
-Pictures_name(const long id)
+Pictures_name(const uint32_t id)
 {
-  u_short i;
+  uint16_t i;
   
   if (pictures == NULL) {
     printf("[!] No pictures loaded\n");
@@ -187,10 +198,10 @@ Pictures_name(const long id)
 }
 
 
-int
-Pictures_index(const long id)
+int32_t
+Pictures_index(const uint32_t id)
 {
-  u_short i;
+  uint16_t i;
   
   if (pictures == NULL) {
     printf("[!] No pictures loaded\n");
@@ -207,10 +218,10 @@ Pictures_index(const long id)
 }
 
 
-long
+int32_t
 Pictures_find(const char *name)
 {
-  u_short i;
+  uint16_t i;
 
   if (pictures == NULL) {
     printf("[!] No pictures loaded\n");
@@ -226,7 +237,7 @@ Pictures_find(const char *name)
 }
 
 
-long
+uint32_t
 Pictures_random_id()
 {
   uint32_t idx;
@@ -241,7 +252,7 @@ Pictures_random_id()
 const Picture8_t *
 Pictures_random()
 {
-  uint32_t idx;
+  uint16_t idx;
 
   assert(pictures != NULL);
   idx = b_rand_int_range(0, pictures->size-1);
