@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2011 Olivier Girondel
+ *  Copyright 1994-2012 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -25,7 +25,7 @@
 
 typedef struct Pictures_s {
   Picture8_t **pics;
-  u_short    size;
+  uint16_t   size;
 } Pictures_t;
 
 extern Pictures_t *pictures;
@@ -34,10 +34,10 @@ extern Pictures_t *pictures;
 void Pictures_new(const char *, const char *);
 void Pictures_delete();
 
-const char *Pictures_name(const long);       
-int Pictures_index(const long);
-long Pictures_find(const char *);
-long Pictures_random_id();
+const char *Pictures_name(const uint32_t);
+int32_t Pictures_index(const uint32_t);
+int32_t Pictures_find(const char *);
+uint32_t Pictures_random_id();
 const Picture8_t *Pictures_random();
 
 
