@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2011 Olivier Girondel
+ *  Copyright 1994-2012 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -74,14 +74,14 @@ Sequence_new(const uint32_t id)
 
 
 void
-Sequence_clear(Sequence_t *s)
+Sequence_clear(Sequence_t *s, const uint32_t new_id)
 {
   GList *tmp;
 
   if (s == NULL)
     xerror("Attempt to Sequence_clear() a NULL sequence\n");
 
-  s->id = 0;
+  s->id = new_id ? new_id : 0;
   
   if (NULL != s->name)
     xfree(s->name);
@@ -123,6 +123,7 @@ Sequence_delete(Sequence_t *s)
 
     if (libbiniou_verbose)
       printf("[s] Freeing sequence id %lu\n", s->id);
+
     tmp = s->layers;
     while (tmp != NULL) {
       Layer_t *l = (Layer_t *)tmp->data;
