@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2011 Olivier Girondel
+ *  Copyright 1994-2012 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -55,7 +55,7 @@ void Sequence_delete(Sequence_t *);
 
 void Sequence_display(const Sequence_t *);
 void Sequence_copy(const Sequence_t *, Sequence_t *);
-void Sequence_clear(Sequence_t *);
+void Sequence_clear(Sequence_t *, const uint32_t);
 void Sequence_changed(Sequence_t *);
 
 void Sequence_insert(Sequence_t *, Plugin_t *);
@@ -65,7 +65,7 @@ void Sequence_remove(Sequence_t *, const Plugin_t *);
 GList *Sequence_find(const Sequence_t *, const Plugin_t *);
 short Sequence_find_position(const Sequence_t *, const Plugin_t *);
 
-void Sequence_save(Sequence_t *, int);
+void Sequence_save(Sequence_t *, int, const int);
 Sequence_t *Sequence_load(const char *);
 
 gint Sequence_sort_func(gconstpointer, gconstpointer);
