@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2011 Olivier Girondel
+ *  Copyright 1994-2012 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -84,7 +84,7 @@ Sequence_write(const Sequence_t *s, const char *filename)
 
 
 void
-Sequence_save(Sequence_t *s, int overwrite)
+Sequence_save(Sequence_t *s, int overwrite, const int is_transient)
 {
   char *filename = NULL;
   gchar *blah = NULL;
@@ -106,19 +106,18 @@ Sequence_save(Sequence_t *s, int overwrite)
     overwrite = 0;
   }
 
-  if (overwrite)
-    printf("[s] Overwriting sequence %lu (%s.xml)\n", s->id, s->name);
-  else {
+  if (!overwrite || is_transient) {
     struct timeval t;
     
     gettimeofday(&t, NULL);
     s->id = t.tv_sec;
-    if (s->name != NULL)
-      xfree(s->name);
-    s->name = g_strdup_printf("%lu", s->id);
-    printf("[s] Saving NEW sequence %lu\n", s->id);
   }
 
+  if (s->name != NULL)
+    xfree(s->name);
+  s->name = g_strdup_printf("%lu", s->id);
+  printf("[s] Saving sequence %lu\n", s->id);
+
   home_dir = g_get_home_dir();
   blah = g_strdup_printf("%s/%s", home_dir, SAVEDIR);
   rmkdir(blah);
