@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2011 Olivier Girondel
+ *  Copyright 1994-2012 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -31,6 +31,7 @@ SequenceManager_new()
   sm = xcalloc(1, sizeof(SequenceManager_t));
   sm->cur = Sequence_new(0);
   sm->next = Sequence_new(0);
+  sm->transient = Sequence_new(0);
 
   SequenceManager_load_banks(sm);
 
@@ -43,10 +44,18 @@ SequenceManager_delete(SequenceManager_t *sm)
 {
   Sequence_delete(sm->cur);
   Sequence_delete(sm->next);
+  Sequence_delete(sm->transient);
   xfree(sm);
 }
 
 
+const int
+SequenceManager_is_transient(const SequenceManager_t *sm, const Sequence_t *s)
+{
+  return (sm->transient == s);
+}
+
+
 void
 SequenceManager_move_selected_front(Sequence_t *seq)
 {
