@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2011 Olivier Girondel
+ *  Copyright 1994-2012 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -27,7 +27,7 @@
 
 
 typedef struct SequenceManager_s {
-  Sequence_t *cur, *next;
+  Sequence_t *cur, *next, *transient;
   GList      *curseq;
 
   /* Banks */
@@ -58,4 +58,6 @@ void SequenceManager_use_bankset(SequenceManager_t *, const u_char);
 void SequenceManager_save_banks(const SequenceManager_t *);
 void SequenceManager_load_banks(SequenceManager_t *);
 
+const int SequenceManager_is_transient(const SequenceManager_t *, const Sequence_t *);
+
 #endif /* __BINIOU_SEQUENCE_MANAGER_H */
