@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2011 Olivier Girondel
+ *  Copyright 1994-2012 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -64,7 +64,7 @@ SequenceManager_event(SequenceManager_t *sm, const Event_t *e)
       SequenceManager_default_layer_mode(sm->cur);
       return 1;
     } else if (e->arg0 == BA_SEQUENCE) {
-      Sequence_clear(sm->cur);
+      Sequence_clear(sm->cur, 0);
       return 1;
     } else
       return 0;
@@ -72,12 +72,12 @@ SequenceManager_event(SequenceManager_t *sm, const Event_t *e)
 
   case BC_SAVE:
     if (e->arg0 == BA_SEQUENCE) {
-      Sequence_save(sm->cur, 0);
+      Sequence_save(sm->cur, 0, SequenceManager_is_transient(sm, sm->cur));
       sm->curseq = sequences->seqs;
       Shuffler_grow_one_left(sequences->shuffler);
       return 1;
     } else if (e->arg0 == BA_OVERWRITE) {
-      Sequence_save(sm->cur, 1);
+      Sequence_save(sm->cur, 1, SequenceManager_is_transient(sm, sm->cur));
       return 1;
     }
     break;
